@@ -11,7 +11,7 @@ except ImportError:
     from http_parser.pyparser import HttpParser
 
 from http_parser.reader import HttpBodyReader
-from http_parser.util import status_reasons
+from http_parser.util import status_reasons, bytes_to_str
 
 HTTP_BOTH = 2
 HTTP_RESPONSE = 1
@@ -52,7 +52,7 @@ class HttpStream(object):
 
         while True:
             try:
-                data = self.next()
+                next(self)
             except StopIteration:
                 if self.parser.is_headers_complete():
                     return
@@ -66,15 +66,16 @@ class HttpStream(object):
         if self.parser.is_headers_complete():
             return True
 
-        data = ""
+        data = []
         if not cond():
             while True:
                 try:
-                    data += self.next()
+                    d = next(self)
+                    data.append(d)
                 except StopIteration:
                     if self.parser.is_headers_complete():
                         return True
-                    raise BadStatusLine(data)
+                    raise BadStatusLine(b"".join(data))
                 if cond():
                     return True
         return True
@@ -182,7 +183,7 @@ class HttpStream(object):
     def __iter__(self):
         return self
 
-    def next(self):
+    def __next__(self):
         if self.parser.is_message_complete():
             raise StopIteration
 
@@ -197,10 +198,12 @@ class HttpStream(object):
         # parse data
         nparsed = self.parser.execute(to_parse, recved)
         if nparsed != recved and not self.parser.is_message_complete():
-            raise ParserError("nparsed != recved (%s != %s)" % (nparsed,
-                recved))
+            raise ParserError("nparsed != recved (%s != %s) [%s]" % (nparsed,
+                recved, bytes_to_str(to_parse)))
 
         if recved == 0:
             raise StopIteration
 
         return to_parse
+
+    next = __next__
