@@ -6,7 +6,12 @@
 import os
 import re
 import sys
-import urlparse
+
+if sys.version_info >= (3,):
+    import urllib.parse as urlparse
+else:
+    import urlparse
+
 import zlib
 
 from http_parser.util import (b, bytes_to_str, IOrderedDict, StringIO,
@@ -105,7 +110,7 @@ class HttpParser(object):
             if hkey in environ:
                 environ[key] = environ.pop(hkey)
 
-        script_name = environ.get('HTTP_SCRIPT_NAME',
+        script_name = environ.get('SCRIPT_NAME',
                 os.environ.get("SCRIPT_NAME", ""))
         if script_name:
             path_info = self._path.split(script_name, 1)[1]
